#!perl
use 5.008;

use strict;
use warnings;
use utf8;

use lib qw(../lib/);

use Test::More;

my $class = 'Text::Guess::Language';

use_ok($class);

my $text =<<TEXT;

SPLOŠNA DEKLARACIJA ČLOVEKOVIH PRAVIC
PREAMBULA
Ker pomeni priznanje prirojenega človeškega dostojanstva vseh članov človeške družbe in njihovih enakih in neodtujljivih pravic temelj svobode, pravičnosti in miru na svetu;

ker sta zanikanje in teptanje človekovih pravic pripeljala do barbarskih dejanj, žaljivih za človeško vest, in ker je bila stvaritev sveta, v katerem bi imeli vsi ljudje svobode govora in verovanja in v katerem ne bi živeli v strahu in pomanjkanju, spoznana za najvišje prizadevanje človeštva;

ker je nujno potrebno, da se pravice človeka zavarujejo z močjo prava, da človek ne bi bil prisiljen zatekati se v skrajni sili k uporu zoper tiranijo in nasilje;

ker je nujno potrebno pospeševati razvoj prijatelskih odnosov med narodi;

ker so ljudstva Združenih narodov ponovno potrdila svojo vero v temeljne človekove pravice osebnosti, v enakopravnost moških in žensk in se odločila, da bodo podpirala družbeni napredek in ustvarjanje boljših življenjskih pogojev v večji svobodi;

ker so se vse države članice zavezale, da bodo, v sodelovanju z Združenimi narodi, pospeševale splošno in resnično spoštovanje človekovih pravic in temeljnih svoboščin;

ker je skupno razumevanje teh pravic in svoboščin največjega pomena za popolno uresničitev te zaveze,

GENERALNA SKUPŠČINA

razglaša

TO SPLOŠNO DEKLARACIJO ČOVEKOVIH PRAVIC kot skupen ideal vseh ljudstev in vseh narodov z namenom, da bi vsi organi družbe in vsi posamezniki, vedno v skladu s to Declaracijo, pri pouku in vzgoji razvijali spoštovanje do teh pravic in svoboščin ter s postopnimi državnimi in mednarodnimi ukrepi zagotovili in zavarovali njihovo splošno in resnično priznanje in spoštovanje, tako med narodi držav članic samih, kakor tudi med ljudstvi ozemelj pod njihovo oblastjo.

1. člen.
Vsi ljudje se rodilo svobodni in imajo enako dostojanstvo in enake pravice. Obdarjeni so z razumom in vestjo in bi morali ravnati grug z grugim kakor bratje.

2. člen.
Vsakdo je upravičen do uživanja vseh pravic in svoboščin, ki so razglašene s to Declaracijo, ne glede na raso, barvo, spol, jezik, vero, politično ali drugo prepričanje, narodno ali socialno pripadnost, premoženje, rojstvo ali kakršnokoli drugo okoliščino.

Nadalje ni dopustno nikakršno razlikovanje glede na politično ali pravno ureditev ali mednarodni položaj dežele ali ozemlja, ki mu kdo pripada, pa naj bo to ozemlje neodvisno, pod skrbništvom, nesamoupravno ali kakorkoli omejeno v svoji suverenosti.

3. člen.
Vsakdo ima pravico do življenja, do prostosti in do osebne varnosti.

4. člen.
Nikogar se ne sme imeti niti v suženjustvu niti v podložništvu; suženjstvo in trgovina s sužnji v kakršnikoli obliki sta prepovedana.

5. člen.
Nikogar se ne sme mučiti ali z njim surovo, nečloveško ali ponižujoče ravnati.

6. člen.
Vsakdo ima povsod pravico do priznanja pravne sposobnosti.

7. člen.
Vsi so enaki pred zakonom, vsi, brez diskriminacije, imajo pravico do enakega pravnega varstva. Vsi imajo pravico do enakega varstva pred sleherno diskriminacijo, ki bi kršila to Declaracijo, kakor tudi pred vsakim ščuvanjem k takšni diskriminaciji.

8. člen.
Vsakdo ima pravico do učinkovitega pravnega sredstva pri pristojnih državnih sodnih oblasteh proti dejanjem, ki kršijo temeljne pravice, priznane mu po ustavi ali zakonu.

9. člen.
Nihče ne sme biti samovoljno zaprt, pridržan ali izgnan.

10. člen.
Vsakdo je pri odločanju o njegovih pravicah in dolžnostih in v primeru kakršnekoli kazenske obtožbe zoper njega upravičen ob polni enakosti do pravičnega in javnega obravnavanja pred neodovisnim in nepristranskim sodiščem.

11. člen.
Vsakdo, ki je obtožen kaznivega dejanja, ima pravico, da velja za nedolžnega, dokler ni spoznan za krivega v skladu za zakonom o javnem postopku, v katerem so mu dane vse možnosti, potrebne za njegovo obrambo.
Nihče ne sme biti spoznan za krivega kateregakoli kaznivega dejanja zaradi kakršnegakoli ravnanja ali opustitve, po notranjem ali mednarodnem pravu. Prav tako se ne sme izreči strožja kazen od tiste, ki je bila predpisana v času storitve kaznivega dejanja.
12. člen.
Nikogar se ne sme nadlegovati s samovoljnim vmešavanjem v njegovo zasebno življenje, v njegovo družino, v njegovo stanovanje ali njegovo dopisovanje in tudi ne z napadi na njegovo čast in ugled. Vsakdo ima pravico do zakonskega varstva pred takšnim vmešavanjem ali takšnimi napadi.

13. člen.
Vsakdo ima pravico do svobodnega gibanja in izbire prebivališče znotraj meja določene države.
Vsakdo ima pravico zapustiti katero koli državo, vklljučno svojo lastno, in vrni ti se v svojo državo.
14.člen.
Vsakdo ima pravico v drugi državah iskati in uživati pribežališče pre preganjanjem.
Na to pravico se ni mogoče sklicevati primeru pregona, ki dejansko temeljih nepolitičnih kaznivih dejanjih ali dejanih ki so v nasprotju s cilji in načeli Združe nih narodov.
15. člen.
Vsakdo ima pravico do državljanstva.
Nikomur se ne sme samovoljno vze državljanstvo ali zakonita pravica do spre membe državljanstva.
16. člen.
Polnoletni moški in žensi imajo brez kakršnihkoli omejitev glede in raso, državljanstvo ali vero, pravico skloniti zakonsko zvezo in ustanoviti družin Upravičeni so do enakih pravic v zvezi zakonsko zvezo, tako med zakonsko zver kot tudi, ko ta preneha.
Zakonska zveza se sme skleniti samo svobodno in polno privolitvijo obeh bodčih zakoncev.
Družina je naravna in temeljna celi družbe in ima pravico do družbenega državnega varstva.
17. člen
Vsakdo ima pravico do prmoženja, tako sam, kakor tudi skupno drugimi.
Nikomur ne sme biti prmoženje samovoljno vzeto.
18. člen.
Vsakdo ima pravico do svobodne misli, vesti in veroizpovedi; ta pravi zajema svodobo spreminjati prepričan in vero kakor tudi nujno svobodno, jav ali zasebno izražanje, bodisi posamezr ali v skupnosti z drugimi, s poučevanjem, v praksi, z bogoslužjem in opravljanjem obredov.

19. člen.
Vsakdo ima pravico do svobode mišljenja in izražanja vštevši pravico, da nihče ne sme biti nadlegovan zaradi svojega mišljenja, in pravico, da lahko vsak išče, sprejema in širi informacije in ideje s kakršnimikoli sredstvi in ne glede na meje.

20. člen.
Vsakdo ima pravico do svobodnega in miroljubnega zbiranja in združevanja.
Nikogar se ne sme prisiliti k članstvu v katerokoli društvo.
21. člen
Vsakdo ima pravico sodelovati pri opravljanju javnih zadev svoje države bodisi neposredno ali po svobodno izbranih predstavnikih.
Vsakdo ima pod enakimi pogoji pravico do javnih služb v svoji državi.
Volja ljudstva je temelj javne oblasti; ta volja se mora izražati v občasnih in poštenih volitvah, ki morajo biti splošne ob načelu enakosti in tajnega glasovanja ali po kakšnem drugem enakovrednem postopku, ki zagotavlja svobodo glasovanja.
22. člen.
Vsakdo ima kot član družbe pravico do socialne varnosti in pravico do uživanja, s pomočjo prizadevanj svojih skupnosti in mednarodnega sodelovanja in v skladu z ureditvijo in sredstvi neke države, ekonomskih, socialnih in kulturnih pravic, nepogrešljivih za njegove dostojansvto in svoboden razvoj njegove osebnosti.

23. člen.
Vsakdo ima pravico do dela in proste izbire zaposlitve, do pravičnih in zadovoljivih delovnih pogojev in do varstva pred nezaposlenostjo.
Vsakdo ima, brez kakršnekoli diskriminacije, pravico do enakega plačila za enako delo.
Vsakdo, kdor dela, ima pravico do pravične in zadovoljive nagrade, ki zagotavlja njemu in njegovi družini človeka vreden obstoj in ki naj se po potrebi dopolni z drugimi sredstvi socialnega varstva.
Vsakdo ima pravico sodelovati pri ustanavljanju sindikata ali pridružiti se sindeikatu za zavarovanje svojih interesov.
24. člen.
Vsakdo ima pravico do počitka in prostega časa, vključno z razumno omejitvijo delovnih ur, in pravico do občasnega plačanega dopusta.

25. člen.
Vsakdo ima pravico do takšne življenjske ravni, ki zagotavlja njemu in njegovi družini zdravje in blagostanje, vključno hrano obleko, stanovanje, zdravniško oskrbo in potrebne socialne usluge; pravico do vastrva v primeru nezaposlenosti, bolezni, delovne nezmožnosti, vdovstva ter starosti ali druge nezmožnosti pridobivanja živlljenjskih sredstev zaradi okoliščin, neodvisnih od njegove volje.
Materinstvo in otroštvo sta upravičena do posebne skrbi in pomoči. Vsi otroci, bodisi da so rojeni kot zakonski ali zunaj zakonske skupnosti, uživajo enako socialno varstvo.
26. člen.
Vsakdo ima pravico do izobrazbe. Izobraževanje je brezplačno vsaj na začetni in temeljni stopnji. ·olanje na začetni stopnji je obvezno. Tehnično in poklicno šolanje mora biti splošno dostopno. Višje šolanje mora biti na osnovi doseženih uspehov vsem enako dostopno.
Izobrazba mora biti usmerjena k polnemu razvoju človekove osebnosti in utrjevanju spoštovanja človekovih pravic in temeljnih svoboščin. Pospeševati mora razumevanje, strpnost in prijateljstvo med vsemi narodi in med rasnimi in verskimi skupinami ter pospeševati dejavnos Združenih narodov za ohranitev miru.
Starši imajo prvo pravico do izbire vrste izobrazbe za svoje otroke.
27. člen.
Vsakdo ima pravico prosto se udeleževati kulturnega življenja svoje skupnosti, uživati umetnost in sodelovati pri napredku znanosti in biti deležen koristi, ki iz nje izhajajo.
Vsakdo ima pravico do varstva moralnih in premoženjskih koristi, ki izhajajo iz kateregakoli znanstvenega, knijiževnega ali umetniškega dela, katerega avtor je.
28. člen.
Vsakdo je upravičen do družbenega in mednarodnega reda, v katerem se lahko v polni meri uresničujejo pravice in svoboščine, določene v tej Declaraciji.

29. člen.
Vsakdo ima dolžnosti do skupnosti, v kateri je edino mogoč svoboden in popoln razvoj njegove osebnosti.
Pri izvanjanju svojih pravic in svoboščin je vsakdo podvržen samo takšnim omejitvam, ki so določene z zakonom, katerih izključni namen je zavarovati obvezno priznanje in spoštovanje pravic in svoboščin drugih ter izpolnjevanje pravičnih zahtev morale, javnega reda in splošne blaginje v demokratični družbi.
Te pravice in svoboščine se v nobenem primeru ne smejo izvajati v nasprotju s cilji in načeli Združenih narodov.
30. člen.
Nobene določbe te Declaracije se ne sme razlagati tako, kot da iz nje izhaja za državo, skupino ali posameznika kakršnakoli pravica do kakršnegakoli delovanja ali dejanja, ki bi hotelo uničiti v njej določene pravice in svoboščine.
TEXT

is(Text::Guess::Language->guess($text),'sl','is sl');

done_testing;
